﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

/// <summary>
/// Template for adding tutorials into the project
/// </summary>
[System.Serializable]
public class TutorialManager : MonoBehaviour
{
    [SerializeField]
    public GameObject tutorialButton;
    [SerializeField]
    private MovementTut firstTutorial;
    templateTut[] allTutorials;
    private void Awake()
    {
        firstTutorial.eventSetting = TStatus.Started;
        allTutorials = gameObject.GetComponents<templateTut>();
    }

    private void Update()
    {
        for(int i = 0; i < allTutorials.Length; i++)
        {
            if(allTutorials[i].eventSetting == TStatus.Redundant)
            {
                Destroy(allTutorials[i]);
            }
        }
    }

    /// <summary>
    /// Displays the button containing the tutorial
    /// </summary>
    /// <param name="tutorialText">The text that the tutorial button is supposed to display</param>
    public void displayTutorial(string tutorialText)
    {
        tutorialButton.SetActive(true);
        tutorialButton.GetComponentInChildren<Text>().text = tutorialText;
        Time.timeScale = 0.0f;
    }

    /// <summary>
    /// Hides the tutorial when the tutorial button is pressed
    /// </summary>
    public void hideTutorial()
    {
        Time.timeScale = 1.0f;
        tutorialButton.SetActive(false);
        for(int i = 0; i < allTutorials.Length; i++)
        {
            if(allTutorials[i].eventSetting == TStatus.Started || allTutorials[i].eventSetting == TStatus.Completing)
            {
                allTutorials[i].eventSetting++;
            }
        }
    }
}